timeseries.Signal.feature_match — GDA Toolbox v1.0 Manual

- GDA Toolbox v1.0 Manual
- Time-Series Data
- timeseries.Signal

- index
- modules
- next
- previous

# timeseries.Signal.feature_match

`Signal.` `feature_match`(other, sigma=1.0, num_samples=1000)

#### Previous topic

timeseries.Signal.feature

#### Next topic

timeseries.Signal.from_pointcloud

- © Copyright 2015-2017, Geometric Data Analytics, Inc.
- Last updated on Jan 07, 2019.
- Created using Sphinx 1.8.2.